@@ -1,9 +1,8 @@
 package Text::Template::Simple;
 use strict;
 use warnings;
-use vars qw( $VERSION );
 
-$VERSION = '0.84';
+our $VERSION = '0.85';
 
 use File::Spec;
 use Text::Template::Simple::Constants qw(:all);
@@ -143,7 +142,7 @@ sub _init {
    $self->[FAKER]          = $self->_output_buffer_var;
    $self->[FAKER_HASH]     = $self->_output_buffer_var('hash');
    $self->[FAKER_SELF]     = $self->_output_buffer_var('self');
-   $self->[INSIDE_INCLUDE] = MINUS_ONE; # must be -1 not 0
+   $self->[INSIDE_INCLUDE] = RESET_FIELD;
    $self->[NEEDS_OBJECT]   =  0; # the template needs $self ?
    $self->[DEEP_RECURSION] =  0; # recursion detector
 
@@ -252,8 +251,8 @@ Where C<hello.tts> has this content:
 
 =head1 DESCRIPTION
 
-This document describes version C<0.84> of C<Text::Template::Simple>
-released on C<15 November 2011>.
+This document describes version C<0.85> of C<Text::Template::Simple>
+released on C<29 January 2012>.
 
 This is a simple template module. There is no extra template/mini 
 language. Instead, it uses Perl as the template language. Templates
@@ -679,7 +678,7 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2011 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2012 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
