@@ -2,12 +2,15 @@ package Text::Template::Simple::Compiler::Safe;
 # Safe compiler. Totally experimental
 use strict;
 use warnings;
-use vars qw($VERSION);
+
 use Text::Template::Simple::Dummy;
 
-$VERSION = '0.84';
+our $VERSION = '0.85';
 
-sub compile { shift; return __PACKAGE__->_object->reval(shift) }
+sub compile {
+   shift;
+   return __PACKAGE__->_object->reval(shift);
+}
 
 sub _object {
    my $class = shift;
@@ -45,8 +48,8 @@ Private module.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.84> of C<Text::Template::Simple::Compiler::Safe>
-released on C<15 November 2011>.
+This document describes version C<0.85> of C<Text::Template::Simple::Compiler::Safe>
+released on C<29 January 2012>.
 
 Safe template compiler.
 
@@ -60,7 +63,7 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2011 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2012 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
